"""
xwsystem Wrapper Package

This is a convenience wrapper that provides 'import xwsystem' functionality.
The actual implementation is in the exonware-xwsystem package.

Company: eXonware.com
Author: Eng. Muhammad AlShehri
Email: connect@exonware.com
"""

# This wrapper package depends on exonware-xwsystem
# When you pip install xwsystem, it automatically installs exonware-xwsystem
# Both import paths then work:
#   - import xwsystem
#   - import exonware.xwsystem

__all__ = []

